@@ -20,7 +20,24 @@ from common.com import *
 from pub_cls_com import *
 '''Date: 2021.03.16'''
 
-def _handle_ex_ret(code_list=['00700'], queryType='tradition', start_date='2021-03-11', end_date='2021-03-12', market=2, unit='1d', page=1, fre=2):
+def _handle_ex_ret(code_list=['00700'], queryType=None, start_date=None, end_date=None, market=2, unit='1d', page=1, fre=2):
+
+    # 查询最长周期: 1年时间
+    if unit != '1d': return '您好,接口暂时不提供日级别以外的数据哟,我们会马不停蹄的加班,尽快把分钟、周和月级别的数据补全!'
+    if market == 3 or market == 1: return '您好,接口暂时不提供美股/A股的数据哟,我们会马不停蹄的加班,尽快把美股的数据补全!'
+    if start_date is None and end_date is None: return '您好,检测到end_date比start_date都是None,请修正后重新请求数据!'
+    if start_date is not None and end_date is None:
+        end_date = start_date
+    if start_date is None and end_date is not None:
+        start_date = end_date
+    if start_date is not None and end_date is not None:
+        if start_date > end_date: return '您好,检测到end_date比start_date要小哟,请修正后重新请求数据!'
+        s_dt = datetime.datetime.strptime(start_date, '%Y-%m-%d')
+        e_dt = datetime.datetime.strptime(end_date, '%Y-%m-%d')
+
+        day_count = (e_dt - s_dt).days
+        if day_count > 365 * 1: return '您好,技术指标接口一次最多只能提供1年的数据哟,如果需要更多的数据,请分段获取!'
+    print('start_date:{}, end_date:{}'.format(start_date, end_date))
 
     body = {
         "codeList": code_list,
@@ -30,15 +47,16 @@ def _handle_ex_ret(code_list=['00700'], queryType='tradition', start_date='2021-
         "endDate": end_date,
         "unit": unit,
         "ifRehabili": fre,
-        "current": page
+        "current": page,
+        "size": 100
     }
-
+    print('body:{}'.format(body))
     df_ = total_handle_req(body=body, URL=BE_TECH_POST_URL)
-
+    print('--->df_:{}'.format(df_))
     return df_
 
 ###### 基础类技术面指标
-def get_sar_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_sar_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取SAR技术指标数据
         Args:
@@ -49,17 +67,16 @@ def get_sar_factor_data(code_list=['00700'], market=2, unit='1d', start_date='20
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回macd的因子数据
-        '''
+        Returns: 返回因子数据
+    '''
     factor_names = ['SecuCode', 'Trend', 'WhetherTurn', 'AF', 'SAR1', 'SAR2', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_obv_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_obv_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取OBV技术指标数据
         Args:
@@ -70,17 +87,16 @@ def get_obv_factor_data(code_list=['00700'], market=2, unit='1d', start_date='20
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
         '''
     factor_names = ['SecuCode', 'OBV', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_boll_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_boll_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取BOLL技术指标数据
         Args:
@@ -91,17 +107,16 @@ def get_boll_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
         '''
     factor_names = ['SecuCode', 'MID', 'MD', 'UPPERValue', 'LOWERValue', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_wr_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_wr_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取WR技术指标数据
         Args:
@@ -112,17 +127,16 @@ def get_wr_factor_data(code_list=['00700'], market=2, unit='1d', start_date='201
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
         '''
     factor_names = ['SecuCode', 'WR6', 'WR10', 'WR13', 'WR34', 'WR89', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_rsi_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_rsi_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取RSI技术指标数据
         Args:
@@ -133,17 +147,16 @@ def get_rsi_factor_data(code_list=['00700'], market=2, unit='1d', start_date='20
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
         '''
     factor_names = ['SecuCode', 'RSI', 'RS', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_kdj_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_kdj_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取kdj技术指标数据
         Args:
@@ -154,17 +167,16 @@ def get_kdj_factor_data(code_list=['00700'], market=2, unit='1d', start_date='20
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权  1 不复权/2 前复权/3 后复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
         '''
     factor_names = ['SecuCode', 'HighestInNine', 'LowestInNine', 'RSV', 'Kvalue', 'Dvalue', 'Jvalue', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_macd_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-22', end_date='2018-12-27', fre=2):
+def get_macd_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
     获取macd技术指标数据
     Args:
@@ -175,14 +187,13 @@ def get_macd_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
         start_date: 开始日期
         end_date: 结束日期
         fre:是否复权  1 不复权/2 前复权/3 后复权
-    Returns: 返回macd的因子数据
+    Returns: 返回因子数据
     '''
     factor_names = ['SecuCode', 'EMA12', 'EMA26', 'DIF', 'DEA', 'MACD', 'TradingDay']
     data_type = 'tradition'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
 def _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre):
@@ -197,21 +208,19 @@ def _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, ma
         market: 市场类型 1 CH/ 2 HK/ 3 USA
         unit: 频率 默认 '1d' 日级别数据
         fre: 是否复权  1 不复权/2 前复权/3 后复权
-
     Returns:
     '''
+
     pageSize = f_data_['totalPage']
     page1_data = f_data_['result']
     res_df = pd.DataFrame(page1_data)
-
     if pageSize > 1:
-        res_df = _get_other_data(res_df, pageSize, data_type, code_list, start_date, end_date, market, unit, fre)
-
+        res_df = _get_other_data(res_df, factor_names, pageSize, data_type, code_list, start_date, end_date, market, unit, fre)
     __ = res_df[factor_names]
-    __ = __
+    __ = __.reset_index(drop=True)
     return __
 
-def _get_other_data(page1_data, page_size, data_type, code_list, start_date, end_date, market, unit, fre=2):
+def _get_other_data(page1_data, factor_names, page_size, data_type, code_list, start_date, end_date, market, unit, fre=2):
     # 获取剩下页码的数据
     df1_ = page1_data.copy()    #pd.DataFrame(page1_data)
     for pageC in range(2, page_size + 1):
@@ -222,7 +231,7 @@ def _get_other_data(page1_data, page_size, data_type, code_list, start_date, end
     return df1_
 
 ##### 衍生类技术面指标
-def get_hbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_hbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Hbeta技术指标数据
         Args:
@@ -237,12 +246,12 @@ def get_hbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date='
     '''
     factor_names = ['SecuCode', 'Hbeta', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_halpha_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_halpha_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Halpha技术指标数据
         Args:
@@ -257,12 +266,12 @@ def get_halpha_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
     '''
     factor_names = ['SecuCode', 'Halpha', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_hsigma_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_hsigma_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Hsigma技术指标数据
         Args:
@@ -277,12 +286,12 @@ def get_hsigma_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
     '''
     factor_names = ['SecuCode', 'Hsigma', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_hmsens_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_hmsens_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Dmsens技术指标数据
         Args:
@@ -297,12 +306,12 @@ def get_hmsens_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
     '''
     factor_names = ['SecuCode', 'Dmsens', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_oilsen_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_oilsen_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Oilsen技术指标数据
         Args:
@@ -317,12 +326,12 @@ def get_oilsen_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
     '''
     factor_names = ['SecuCode', 'Oilsen', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_dsbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_dsbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Dsbeta技术指标数据
         Args:
@@ -337,12 +346,12 @@ def get_dsbeta_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
     '''
     factor_names = ['SecuCode', 'Dsbeta', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_cmra_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_cmra_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Cmra技术指标数据
         Args:
@@ -357,12 +366,12 @@ def get_cmra_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
     '''
     factor_names = ['SecuCode', 'Cmra', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_stom_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_stom_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Stom技术指标数据
         Args:
@@ -377,12 +386,12 @@ def get_stom_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
     '''
     factor_names = ['SecuCode', 'Stom', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_stoq_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_stoq_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Stoq技术指标数据
         Args:
@@ -397,12 +406,12 @@ def get_stoq_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
     '''
     factor_names = ['SecuCode', 'Stoq', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_stoa_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_stoa_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Stoa技术指标数据
         Args:
@@ -417,12 +426,12 @@ def get_stoa_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
     '''
     factor_names = ['SecuCode', 'Stoa', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_dastd_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_dastd_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Dastd技术指标数据
         Args:
@@ -437,12 +446,12 @@ def get_dastd_factor_data(code_list=['00700'], market=2, unit='1d', start_date='
     '''
     factor_names = ['SecuCode', 'Dastd', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_season_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_season_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Season技术指标数据
         Args:
@@ -453,16 +462,16 @@ def get_season_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权 默认不复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
     '''
     factor_names = ['SecuCode', 'Season', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_rstr_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-20', end_date='2018-12-27', fre=2):
+def get_rstr_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Rstr技术指标数据
         Args:
@@ -473,16 +482,17 @@ def get_rstr_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权 默认不复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
     '''
     factor_names = ['SecuCode', 'Rstr', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    #
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_strev_factor_data(code_list=['00700'], market=2, unit='1d', start_date='2018-12-27', end_date='2018-12-27', fre=2):
+def get_strev_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取strev技术指标数据
         Args:
@@ -493,14 +503,31 @@ def get_strev_factor_data(code_list=['00700'], market=2, unit='1d', start_date='
             start_date: 开始日期
             end_date: 结束日期
             fre:是否复权 默认不复权
-        Returns: 返回macd的因子数据
+        Returns: 返回因子数据
     '''
     factor_names = ['SecuCode', 'Strev', 'Trading_Day']
     data_type = 'derived'
-    f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
-
+    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+    # if t_typeof(f_data_) == 'str':return f_data_
+    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
+def total_cls_handle(code_list, factor_names, data_type=None, start_date=None, end_date=None, market=None, unit=None, fre=None):
+    # 统一处理返回值
+    try:
+        code_list = list(set(code_list))
+        f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
+        print('f_data_:{}'.format(f_data_))
+        if t_typeof(f_data_) == 'str': return f_data_
+        if [] == f_data_['result']:
+            return '您好, 检测到时间区间的存在问题, 导致取到的数据为空, 请修改时间后重新请求数据.'
+
+        __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
+    except:
+        __ = '您好, 检测到入参存在问题, 导致取到的数据为空, 请修改后重新请求数据.'
+    return __
+
+
 if __name__ == '__main__':
     pass
